<xsl:stylesheet xmlns:xsl='http://www.w3.org/1999/XSL/Transform' xmlns:saxon="http://icl.com/saxon" extension-element-prefixes="saxon" version="1.0" xmlns:sch="http://www.ascc.net/xml/schematron">  

<xsl:import href="../../../share/XSLT/bottomLinks.xsl"/>
<xsl:import href="../../../share/XSLT/descriptionTop.xslt"/>
<xsl:import href="../../../share/XSLT/indexMenu.xslt"/>

<xsl:param name="pwd"/>

<xsl:variable name="tab">&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;&#160;</xsl:variable>


<xsl:param name="basePath"/>

<xsl:variable name="menu">
  <groups xmlns="">
    <group id="short" href="./short.html" title="Properties"/>
    <group id="long"  href="./long.html"  title="Properties - all"/>
    <group id="aural" href="./aural.html" title="Aural"/>
  </groups>
</xsl:variable>

<xsl:variable name="zvonItemid" select="document('../Data/frontpage.xml')/frontPage/@idref"/>


<xsl:key name="property" match="property" use="substring-before(@name,'-')"/>
<xsl:key name="exampleList" match="CSS2ReferenceExamples/example" use="@name"/>


<xsl:template match="/">
  <html>
    <head>
      <title>Zvon CSS2 reference</title>
    </head>
    <frameset cols="250,*">
      <frame name="mainIndex" src="short.html"/>
      <frame name="mainWindow" src="introduction.html"/>
    </frameset>
  </html>
  <xsl:document href="{$pwd}Output/introduction.html">
    <html>
      <head>
	<link rel="stylesheet" type="text/css" href="../CSS/style.css"/>
      </head>
      <body>
	<h2>JJ, MN</h2>
	<h1>CSS 2 Reference</h1>
      </body>
    </html>
  </xsl:document>
  <xsl:apply-templates/>
</xsl:template>

<xsl:template match="CSS2Reference">
  <xsl:document href="{$pwd}Output/long.html">
    <html>
      <head>
	<link rel="stylesheet" type="text/css" href="../CSS/style.css"/>
      </head>
      <body>

      <xsl:call-template name="index-header">
	<xsl:with-param name="on">long</xsl:with-param>
	<xsl:with-param name="id" select="$zvonItemid"/>
      </xsl:call-template>

      <table>
	<xsl:apply-templates select="property[not(@section='Auralstylesheets')]" mode="longIndex">
	  <xsl:sort select="@name"/>
	</xsl:apply-templates>
      </table>
    </body>
  </html>
</xsl:document>

  <xsl:document href="{$pwd}Output/short.html">
    <html>
      <head>
	<link rel="stylesheet" type="text/css" href="../CSS/style.css"/>
      </head>
      <body>

      <xsl:call-template name="index-header">
	<xsl:with-param name="on">short</xsl:with-param>
	<xsl:with-param name="id" select="$zvonItemid"/>
      </xsl:call-template>

      <table>
	<xsl:apply-templates select="property[not(@section='Auralstylesheets')]" mode="shortIndex">
	  <xsl:sort select="@name"/>
	</xsl:apply-templates>
      </table>
    </body>
  </html>
</xsl:document>

  <xsl:document href="{$pwd}Output/aural.html">
    <html>
      <head>
	<link rel="stylesheet" type="text/css" href="../CSS/style.css"/>
      </head>
      <body>

      <xsl:call-template name="index-header">
	<xsl:with-param name="on">aural</xsl:with-param>
	<xsl:with-param name="id" select="$zvonItemid"/>
      </xsl:call-template>
      
      <table cellpadding="3">
	<xsl:apply-templates select="property[@section='Auralstylesheets']" mode="longIndex">
	  <xsl:sort select="@name"/>
	</xsl:apply-templates>
      </table>
    </body>
  </html>
</xsl:document>

</xsl:template>

<xsl:template match="property" mode="longIndex">
    <tr><td><a href="prop_{@name}.html" target="mainWindow"><xsl:value-of select="@name"/></a></td></tr>
    <xsl:apply-templates select="." mode="description"/>
</xsl:template>

<xsl:template match="property" mode="shortIndex">
  <xsl:if test="not(contains(@name,'-'))">
    <tr><td><a href="prop_{@name}.html" target="mainWindow"><xsl:value-of select="@name"/></a></td></tr>
    <xsl:apply-templates select="." mode="shortDescription"/>
  </xsl:if>
</xsl:template>

<xsl:template match="property" mode="description">
  <xsl:document href="{$pwd}Output/prop_{@name}.html">
    <html>
      <head>
	<link rel="stylesheet" type="text/css" href="../CSS/style.css"/>
      </head>
      <body>

	<xsl:call-template name="descriptionTop"/>

	<br/>
	<a class="standard" href="../Standard/{@standard}">Go to Standard</a>
	<br/>

	<table>
	  <tr>
	    <td>Property:</td>
	    <td>
	      <xsl:choose>
		<xsl:when test="contains(@name,'-') and
                   not(
                          @name = 'empty-cells' 
                       or @name = 'caption-side'
                       or @name = 'counter-increment'
                       or @name = 'counter-reset'
                       or @name = 'letter-spacing'
                       or @name = 'line-height'
                       or @name = 'list-style'
                       or @name = 'list-style-image'
                       or @name = 'list-style-position'
                       or @name = 'list-style-type'
                       or @name = 'marker-offset'
                       or @name = 'max-height'
                       or @name = 'max-width'
                       or @name = 'min-height'
                       or @name = 'min-width'
                       or @name = 'speak-header'
                       or @name = 'table-layout'
                       or @name = 'text-align'
                       or @name = 'text-decoration'
                       or @name = 'text-indent'
                       or @name = 'text-shadow'
                       or @name = 'text-transform'
                       or @name = 'unicode-bidi'
                       or @name = 'vertical-align'
                       or @name = 'white-space'
                       or @name = 'word-spacing'
                       or @name = 'z-index'
                       or @name = 'play-during'
                       or @name = 'speech-rate'
                       or @name = 'voice-family'
                    )">
 <!-- osetreni vyjimek,
 ktere maji pomlcku a nejsou sub-property -->
		  <a href="prop_{substring-before(@name,'-')}.html">
		    <xsl:value-of select="substring-before(@name,'-')"/>
		  </a>
		  <xsl:text>-</xsl:text>
		  <xsl:value-of select="substring-after(@name,'-')"/>
		</xsl:when>
		<xsl:otherwise>
		  <xsl:value-of select="@name"/>
		</xsl:otherwise>
	      </xsl:choose>
	    </td>
	  </tr>
	  <xsl:apply-templates/>
	  <xsl:if test="key('property',@name)">
	    <tr>
	      <td>Sub-properties:</td>
	      <td>
		<xsl:apply-templates select="key('property',@name)" mode="descriptionIndex">
		  <xsl:sort select="@name"/>
		</xsl:apply-templates>
	      </td>
	    </tr>
	  </xsl:if>
	</table>
	<xsl:variable name="idrefs" select="normalize-space(key('exampleList',@name)/@idrefs)"/>
	<xsl:if test="$idrefs">
	  <h3>Examples:</h3>
	  <xsl:apply-templates select="id($idrefs)"/>
	</xsl:if>


      <xsl:call-template name="bottomLinks"/>


      </body>
    </html>
  </xsl:document>
</xsl:template>

<xsl:template match="property" mode="descriptionIndex">
      <a href="prop_{@name}.html"><xsl:value-of select="@name"/></a>
      <xsl:if test="not(position()=last())"> | </xsl:if>
</xsl:template>

<xsl:template match='value'>
  <tr>
    <td>Value:</td>
    <td><xsl:apply-templates/></td>
  </tr>
</xsl:template>

<xsl:template match='initial'>
  <tr>
    <td>Initial:</td>
    <td><xsl:apply-templates/></td>
  </tr>
</xsl:template>

<xsl:template match='appliesTo'>
  <tr>
    <td>Applies to:</td>
    <td><xsl:apply-templates/></td>
  </tr>
</xsl:template>

<xsl:template match='inherited'>
  <tr>
    <td>Inherited:</td>
    <td><xsl:apply-templates/></td>
  </tr>
</xsl:template>

<xsl:template match='percentages'>
  <tr>
    <td>Percentages:</td>
    <td><xsl:apply-templates/></td>
  </tr>
</xsl:template>

<xsl:template match='media'>
  <tr>
    <td>Media:</td>
    <td><xsl:apply-templates/></td>
  </tr>
</xsl:template>

<xsl:template match="prop">
  &lt;<xsl:value-of select="@name"/>&gt;
</xsl:template>


<xsl:template match="example[not(@aural)]">
  <xsl:for-each select="css">
    <xsl:document href="{$pwd}Output/{generate-id()}.css" method="text">
      <xsl:value-of select="."/>
    </xsl:document>
    <xsl:document href="{$pwd}Output/{generate-id()}.xml" method="xml">
      <xsl:processing-instruction name="xml-stylesheet">href="<xsl:value-of select="generate-id()"/>.css" type="text/css"</xsl:processing-instruction>
      <xsl:copy-of select="../source/node()"/>
    </xsl:document>
    
    <br/>
    <table border="1" cellpadding="10">
      <tr><td>
	<xsl:apply-templates select="../source/node()" mode="print"/>
      </td><td>
	<a target="_blank" href="{generate-id()}.xml">View</a><br/>
	<xsl:apply-templates select="."/>
      </td></tr>
    </table>
  </xsl:for-each>
</xsl:template>

<xsl:template match="css">
  <xsl:call-template name="cssLine">
    <xsl:with-param name="data"><xsl:value-of select="."/></xsl:with-param>
  </xsl:call-template>
</xsl:template>

<xsl:template name="cssLine">
  <xsl:param name="data"/>
  <xsl:variable name="first">
    <xsl:choose>
      <xsl:when test="contains($data,'&#xA;')">
        <xsl:value-of select="substring-before($data,'&#xA;')"/>
      </xsl:when>
      <xsl:otherwise><xsl:value-of select="$data"/></xsl:otherwise>
    </xsl:choose>
  </xsl:variable>
  <xsl:variable name="rest">
    <xsl:value-of select="substring-after($data,'&#xA;')"/>
  </xsl:variable>
  
  <xsl:call-template name="processCSS">
    <xsl:with-param name="data" select="$first"/>
  </xsl:call-template>

  <xsl:if test="not($first='')">
    <br/>
  </xsl:if>

  <xsl:if test="not($rest='')">
    <xsl:call-template name="cssLine">
      <xsl:with-param name="data"><xsl:value-of select="$rest"/></xsl:with-param>
    </xsl:call-template>
  </xsl:if>

</xsl:template>

<xsl:template name="processCSS">
  <xsl:param name="data"/>
  <xsl:value-of select="$data"/>
</xsl:template>

<xsl:template match="*" mode="print">
  <xsl:variable name="indent" select="substring($tab,1,(count(ancestor::*)-2)*5)"/>
  <br/>
  <xsl:value-of select="$indent"/>
  <xsl:text>&lt;</xsl:text>
  <xsl:value-of select="name()"/>
  <xsl:apply-templates select="@*" mode="print"/>
  <xsl:text>&gt;</xsl:text>
  <xsl:apply-templates mode="print"/>
  <xsl:if test="*">
    <br/>
    <xsl:value-of select="$indent"/>
  </xsl:if>
  <xsl:text>&lt;/</xsl:text>
  <xsl:value-of select="name()"/>
  <xsl:text>&gt;</xsl:text>
</xsl:template>

<xsl:template match="@*" mode="print">
  <xsl:text> </xsl:text>
  <xsl:value-of select="name()"/>
  <xsl:text> = "</xsl:text>
  <xsl:value-of select="."/>
  <xsl:text>"</xsl:text>
</xsl:template>


<xsl:template match="*"/>
<xsl:template match="*" mode="shortDescription"/>


<xsl:template match="example[@aural]" priority="10">
  <xsl:for-each select="css">
    <xsl:document href="{$pwd}Output/{generate-id()}.css" method="text">
      <xsl:value-of select="."/>
    </xsl:document>
    <xsl:document href="{$pwd}Output/{generate-id()}.xml" method="xml">
      <xsl:processing-instruction name="xml-stylesheet">href="<xsl:value-of select="generate-id()"/>.css" type="text/css"</xsl:processing-instruction>
      <xsl:copy-of select="../source/node()[not(name()='sable')]"/>
    </xsl:document>
    
    <br/>
    <table border="1" cellpadding="10">
      <tr><td>
	<xsl:apply-templates select="../source/node()[not(name()='sable')]" mode="print"/>
      </td><td>
	<a target="_blank" href="{generate-id()}.xml">Play</a><br/>
	<a target="_blank" href="../OutputAural/{ancestor::example/@id}.sable.wav">Play simulation .wav</a><br/>
	<xsl:apply-templates select="."/>
      </td></tr>
    </table>
  </xsl:for-each>
</xsl:template>


<xsl:template match="sable" priority="10"/>



<xsl:template name="descriptionTop">
  <xsl:variable name="id" select="document('../Data/frontpage.xml')/frontPage/@idref"/>
  <xsl:call-template name="share_descriptionTop">
    <xsl:with-param name="id" select="$id"/>
  </xsl:call-template>
</xsl:template>



</xsl:stylesheet>
